# Data Sources

This page documents the raw data sources that have been used as the basis for this analysis. 

## UHBW Data Sources

## BNSSG ICB Data Sources

Access to regional patient hospital episode statistics and primary care data was available from the Bristol, North Somerset and South Gloucestershire Integrated Care Board (BNSSG ICB). 

